#!/usr/bin/env perl
##############################################################################
# As with version 1.61.16, streamripper includes a new feature: the ability to
# rip from external metadata. It can be used for recording streams that do not
# send artist or title information using metadata, but instead send this
# information using other means. 
#  
# For example, some streams update the current artist and title using html or
# xml. Another example is icecast 1.x, which sends metadata through a UDP
# socket.
#  
# Streamripper can get artist and title information from these kinds of streams
# using a helper application, specified using the -E option. The helper
# application needs to find the title and artist info, and write it to stdout.
# Streamripper reads the stdout of the helper program, and uses it to split the
# tracks accordingly.
#  
# The example below is a helper application, written in perl, that can be used
# to fetch external metadata from an xml file on a remote web site. 
#
# This is an example script that sends external metadata to streamripper.
# It implements an external program that:
#   1) Fetches a web page
#   2) Searches the web page for the artist and title information
#   3) Sends the information to streamripper on stdout
#
# You need libwww-perl installed to run this script.
#
# To use this script:
#   streamripper URL -E "perl this_script META_URL"
###############################################################################
use LWP::Simple;
$url = $ARGV[0];

while (1) {
    # Fetch xml file at location $url
    my $content = get $url;

    # Get the artist and title
    if ($content =~ m/title="(.*)" artist="(.*)"/) {
        $title = "TITLE=$1\n";
        $artist = "ARTIST=$2\n";
        $end_of_record = ".\n";
        $meta_data = $title . $artist . $end_of_record;
        # Send to streamripper
        syswrite (STDOUT, $meta_data, length($meta_data));
    }
    sleep (10);
}
